==> ocrd-2.8.3.tar.gz: ocrd-2.8.3/ocrd/cli/bashlib.py <==
from __future__ import print_function
import sys
import click

from ocrd.constants import BASHLIB_FILENAME
import ocrd_utils.constants
import ocrd_models.constants

# ----------------------------------------------------------------------
# ocrd bashlib
# ----------------------------------------------------------------------

@click.group('bashlib')
def bashlib_cli():
    """
    Work with bash library
    """

# ----------------------------------------------------------------------
# ocrd bashlib filename
# ----------------------------------------------------------------------

@bashlib_cli.command('filename')
def bashlib_filename():
    """
    Dump the bash library filename for sourcing by shell scripts
    """
    print(BASHLIB_FILENAME)

@bashlib_cli.command('constants')
@click.argument('name')
def bashlib_constants(name):
    """
    Query constants from ocrd_utils and ocrd_models
    """
    if name in ['*', 'KEYS', '__all__']:
        for symbol in ocrd_utils.constants.__all__:
            print(symbol)
        for symbol in ocrd_models.constants.__all__:
            print(symbol)
    elif (name in ocrd_utils.constants.__all__ or
          name in ocrd_models.constants.__all__):
        if name in ocrd_utils.constants.__all__:
            constant = ocrd_utils.constants.__dict__[name]
        else:
            constant = ocrd_models.constants.__dict__[name]
        if isinstance(constant, dict):
            # make this bash-friendly (show initialization for associative array)
            for key in constant:
                print("[%s]=%s" % (key, constant[key]), end=' ')
        else:
            print(constant)
    else:
        print("ERROR: name '%s' is not a known constant" % name, file=sys.stderr)
        sys.exit(1)

==> ocrd-2.12.6.tar.gz: ocrd-2.12.6/ocrd/cli/bashlib.py <==
from __future__ import print_function
import sys
import click

from ocrd.constants import BASHLIB_FILENAME
import ocrd.constants
import ocrd_utils.constants
import ocrd_models.constants
import ocrd_validators.constants

# ----------------------------------------------------------------------
# ocrd bashlib
# ----------------------------------------------------------------------

@click.group('bashlib')
def bashlib_cli():
    """
    Work with bash library
    """

# ----------------------------------------------------------------------
# ocrd bashlib filename
# ----------------------------------------------------------------------

@bashlib_cli.command('filename')
def bashlib_filename():
    """
    Dump the bash library filename for sourcing by shell scripts
    """
    print(BASHLIB_FILENAME)

@bashlib_cli.command('constants')
@click.argument('name')
def bashlib_constants(name):
    """
    Query constants from ocrd_utils and ocrd_models
    """
    all_constants = {}
    for src in [ocrd.constants, ocrd_utils.constants, ocrd_models.constants, ocrd_validators.constants]:
        for k in src.__all__:
            all_constants[k] = src.__dict__[k]
    if name in ['*', 'KEYS', '__all__']:
        print(sorted(all_constants.keys()))
    if name not in all_constants:
        print("ERROR: name '%s' is not a known constant" % name, file=sys.stderr)
        sys.exit(1)
    val = all_constants[name]
    if isinstance(val, dict):
        # make this bash-friendly (show initialization for associative array)
        for key in val:
            print("[%s]=%s" % (key, val[key]), end=' ')
    else:
        print(val)
